@@ -20,29 +20,18 @@ loaded dice is .05 and the probability of switching from loaded to fair is
 
 
 # standard modules
-import os
 import random
 import unittest
+import warnings
 
-# biopython
-from Bio import Alphabet
-from Bio.Seq import MutableSeq
-from Bio.Seq import Seq
+from Bio import BiopythonDeprecationWarning
 
-# HMM stuff we are testing
-from Bio.HMM import MarkovModel
-from Bio.HMM import Trainer
-from Bio.HMM import Utilities
-
-
-if os.name == "java":
-    from Bio import MissingExternalDependencyError
-
-    # This is a slight miss-use of MissingExternalDependencyError,
-    # but it will do in the short term to skip this unit test on Jython
-    raise MissingExternalDependencyError(
-        "This test can cause a fatal error on Jython with some versions of Java"
-    )
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore", category=BiopythonDeprecationWarning)
+    # HMM stuff we are testing
+    from Bio.HMM import MarkovModel
+    from Bio.HMM import Trainer
+    from Bio.HMM import Utilities
 
 
 # whether we should print everything out. Set this to zero for
@@ -51,45 +40,8 @@ VERBOSE = 0
 
 
 # -- set up our alphabets
-class DiceRollAlphabet(Alphabet.Alphabet):
-    letters = ["1", "2", "3", "4", "5", "6"]
-
-
-class DiceTypeAlphabet(Alphabet.Alphabet):
-    letters = ["F", "L"]
-
-
-# -- useful functions
-def _loaded_dice_roll(chance_num, cur_state):
-    """Generate a loaded dice roll based on the state and a random number."""
-    if cur_state == "F":
-        if chance_num <= (float(1) / float(6)):
-            return "1"
-        elif chance_num <= (float(2) / float(6)):
-            return "2"
-        elif chance_num <= (float(3) / float(6)):
-            return "3"
-        elif chance_num <= (float(4) / float(6)):
-            return "4"
-        elif chance_num <= (float(5) / float(6)):
-            return "5"
-        else:
-            return "6"
-    elif cur_state == "L":
-        if chance_num <= (float(1) / float(10)):
-            return "1"
-        elif chance_num <= (float(2) / float(10)):
-            return "2"
-        elif chance_num <= (float(3) / float(10)):
-            return "3"
-        elif chance_num <= (float(4) / float(10)):
-            return "4"
-        elif chance_num <= (float(5) / float(10)):
-            return "5"
-        else:
-            return "6"
-    else:
-        raise ValueError("Unexpected cur_state %s" % cur_state)
+dice_roll_alphabet = ("1", "2", "3", "4", "5", "6")
+dice_type_alphabet = ("F", "L")
 
 
 def generate_rolls(num_rolls):
@@ -102,15 +54,19 @@ def generate_rolls(num_rolls):
     """
     # start off in the fair state
     cur_state = "F"
-    roll_seq = MutableSeq("", DiceRollAlphabet())
-    state_seq = MutableSeq("", DiceTypeAlphabet())
+    roll_seq = []
+    state_seq = []
+    loaded_weights = [0.1, 0.1, 0.1, 0.1, 0.1, 0.5]
     # generate the sequence
     for roll in range(num_rolls):
         state_seq.append(cur_state)
-        # generate a random number
-        chance_num = random.random()
         # add on a new roll to the sequence
-        new_roll = _loaded_dice_roll(chance_num, cur_state)
+        if cur_state == "F":
+            new_rolls = random.choices(dice_roll_alphabet)
+        elif cur_state == "L":
+            new_rolls = random.choices(dice_roll_alphabet, weights=loaded_weights)
+        new_roll = new_rolls[0]
+
         roll_seq.append(new_roll)
         # now give us a chance to switch to a new state
         chance_num = random.random()
@@ -120,14 +76,14 @@ def generate_rolls(num_rolls):
         elif cur_state == "L":
             if chance_num <= 0.1:
                 cur_state = "F"
-    return roll_seq.toseq(), state_seq.toseq()
+    return roll_seq, state_seq
 
 
 class TestHMMCasino(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls.mm_builder = MarkovModel.MarkovModelBuilder(
-            DiceTypeAlphabet(), DiceRollAlphabet()
+            dice_type_alphabet, dice_roll_alphabet
         )
         cls.mm_builder.allow_all_transitions()
         cls.mm_builder.set_random_probabilities()
@@ -144,19 +100,19 @@ class TestHMMCasino(unittest.TestCase):
             print(trained_mm.transition_prob)
             print(trained_mm.emission_prob)
         test_rolls, test_states = generate_rolls(300)
-        predicted_states, prob = trained_mm.viterbi(test_rolls, DiceTypeAlphabet())
+        predicted_states, prob = trained_mm.viterbi(test_rolls, dice_type_alphabet)
         if VERBOSE:
-            print("Prediction probability: %f" % prob)
+            print(f"Prediction probability: {prob:f}")
             Utilities.pretty_print_prediction(test_rolls, test_states, predicted_states)
 
     def test_baum_welch_training_without(self):
         """Baum-Welch training without known state sequences."""
-        training_seq = Trainer.TrainingSequence(self.rolls, Seq("", DiceTypeAlphabet()))
+        training_seq = Trainer.TrainingSequence(self.rolls, ())
 
         def stop_training(log_likelihood_change, num_iterations):
             """Tell the training model when to stop."""
             if VERBOSE:
-                print("ll change: %f" % log_likelihood_change)
+                print(f"ll change: {log_likelihood_change:f}")
             if log_likelihood_change < 0.01:
                 return 1
             elif num_iterations >= 10:
@@ -171,9 +127,9 @@ class TestHMMCasino(unittest.TestCase):
             print(trained_mm.transition_prob)
             print(trained_mm.emission_prob)
         test_rolls, test_states = generate_rolls(300)
-        predicted_states, prob = trained_mm.viterbi(test_rolls, DiceTypeAlphabet())
+        predicted_states, prob = trained_mm.viterbi(test_rolls, dice_type_alphabet)
         if VERBOSE:
-            print("Prediction probability: %f" % prob)
+            print(f"Prediction probability: {prob:f}")
             Utilities.pretty_print_prediction(
                 self.test_rolls, test_states, predicted_states
             )
